import type { Attributes } from '@/types/DrupalAttribute';
import type { ForwardedRef } from 'react';

import { forwardRef } from 'react';
import { Select as SelectRadixThemes } from '@radix-ui/themes';
import { SELECT_ITEM_EMPTY_STRING } from '@/utils/function-utils';

import styles from './Select.module.css';

const Select = forwardRef(function Select(
  {
    value,
    onValueChange,
    options,
    attributes,
  }: {
    value: string;
    onValueChange: (value: string) => void;
    options: { value: string; label: string }[];
    attributes: Attributes;
  },
  ref: ForwardedRef<HTMLButtonElement>,
) {
  const { id, ...remainingAttributes } = attributes;
  return (
    <SelectRadixThemes.Root
      value={value}
      {...remainingAttributes}
      onValueChange={onValueChange}
    >
      <SelectRadixThemes.Trigger
        {...(id && { id: id as string })}
        className={styles.trigger}
        ref={ref}
      />
      <SelectRadixThemes.Content>
        {options?.map((option, index) => (
          // Radix select items can't accept empty strings in the value prop, so
          // use a placeholder that the onChange callback will convert back to
          // an empty string when selected.
          <SelectRadixThemes.Item
            key={index}
            value={option.value || SELECT_ITEM_EMPTY_STRING}
          >
            {option.label}
          </SelectRadixThemes.Item>
        ))}
      </SelectRadixThemes.Content>
    </SelectRadixThemes.Root>
  );
});

export default Select;
